@@ -330,11 +330,14 @@ public:
     void setDisambiguation(const QString &d) { m_disambiguation = d; }
     QString comment() const                  { return m_comment; }
     void setComment(const QString &comment)  { m_comment = comment; }
+    QString id() const                       { return m_id; }
+    void setId(const QString &id)            { m_id = id; }
 
 private:
     bool m_translatable;
     QString m_disambiguation;
     QString m_comment;
+    QString m_id;
 };
 
 // -------------- StringValue: Returned by the property sheet for strings
